@@ -5,7 +5,7 @@ Weasel::Driver::Selenium2 - Weasel driver wrapping Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ This module wraps L<Selenium::Remote::Driver>, version 2.
 
 
 package Weasel::Driver::Selenium2;
-$Weasel::Driver::Selenium2::VERSION = '0.13';
+$Weasel::Driver::Selenium2::VERSION = '0.14';
 use strict;
 use warnings;
 
@@ -298,8 +298,14 @@ sub get_attribute {
     my $value;
     $value = $element->get_attribute($att)  # Try with property/attribute
         if $self->_driver->{is_wd3};
-    return $value
-        // $element->get_attribute($att,1); # Force using attribute
+    if (ref $value) {
+        # there is a bug in Selenium::Remote::Driver which returns a
+        # hash reference when asked for an element's "id", in some cases
+        # when running against a WebDriver 3 implementation
+        $value = undef;
+    }
+    $value //= $element->get_attribute($att,1); # Force using attribute
+    return $value;
 }
 
 =item get_page_source($fh)
